##
##  apache-apreq.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2022 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         apache-apreq
Summary:      Apache Extension: Perl Scripting Language
URL:          http://httpd.apache.org/apreq/
Vendor:       Lincoln Stein, Doug MacEachern et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Web
License:      ASF
Version:      2.17
Release:      20220826

#   package options
%option       with_perl  no

#   list of sources
Source0:      http://www.apache.org/dist/httpd/libapreq/libapreq2-%{version}.tar.gz
Source1:      apache-apreq.conf
Patch0:       apache-apreq.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, perl-openpkg
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  apache
PreReq:       apache
%if "%{with_perl}" == "yes"
BuildPreReq:  apache-perl, perl, perl-openpkg
PreReq:       apache-perl, perl
%endif

%description
    libapreq is a C library with associated modules for manipulating
    client request data via the Apache API. It optionally also includes
    language bindings for Perl (Apache::Request and Apache::Cookie). The
    functionality includes: parsing of application/x-www-form-urlencoded
    data, parsing of multipart/form-data and parsing of HTTP cookies.

%track
    prog apache-apreq = {
        version   = %{version}
        url       = http://www.apache.org/dist/httpd/libapreq/
        regex     = libapreq2-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n libapreq2-%{version}
    %patch -p0

%build
    #   configure package
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    LIBS="-lapr -lexpat" \
    ./configure \
        --prefix="%{l_prefix}" \
%if "%{with_perl}" == "yes"
        --enable-perl-glue \
%else
        --disable-perl-glue \
%endif
        --with-perl="%{l_prefix}/bin/perl" \
        --with-apache2-apxs="%{l_prefix}/sbin/apxs"

    #   build package
    %{l_make} %{l_mflags}

%install
    #   install package
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"

    #   strip down installation files
    rm -f $RPM_BUILD_ROOT%{l_prefix}/libexec/apache/mod_apreq2.a
    rm -f $RPM_BUILD_ROOT%{l_prefix}/libexec/apache/mod_apreq2.la
%if "%{with_perl}" == "yes"
    %{l_prefix}/bin/perl-openpkg prepare
    %{l_prefix}/bin/perl-openpkg -F perl-openpkg-files fixate cleanup
%else
    >perl-openpkg-files
%endif

    #   install default configuration file
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/apache/apache.d
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE apache-apreq.conf} $RPM_BUILD_ROOT%{l_prefix}/etc/apache/apache.d/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} `cat perl-openpkg-files` \
        '%config %{l_prefix}/etc/apache/apache.d/apache-apreq.conf'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} apache status 2>/dev/null`
    [ ".$apache_active" = .yes ] && %{l_rc} apache restart
    exit 0

